# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class NetCDFTimeseriesSourcesSinks(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'multiplier': 'float',
        'simulation': 'str',
        'offset': 'int',
        'duration': 'int',
        'timestamps': 'list[int]',
        'interval': 'int',
        'values_reference': 'str',
        'units': 'str',
        'file': 'FileReadOnly',
        'fill_value': 'str',
        'id': 'int',
        'uid': 'str'
    }

    attribute_map = {
        'url': 'url',
        'multiplier': 'multiplier',
        'simulation': 'simulation',
        'offset': 'offset',
        'duration': 'duration',
        'timestamps': 'timestamps',
        'interval': 'interval',
        'values_reference': 'values_reference',
        'units': 'units',
        'file': 'file',
        'fill_value': 'fill_value',
        'id': 'id',
        'uid': 'uid'
    }

    def __init__(self, url=None, multiplier=None, simulation=None, offset=None, duration=None, timestamps=None, interval=None, values_reference=None, units=None, file=None, fill_value=None, id=None, uid=None, local_vars_configuration=None):  # noqa: E501
        """NetCDFTimeseriesSourcesSinks - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._multiplier = None
        self._simulation = None
        self._offset = None
        self._duration = None
        self._timestamps = None
        self._interval = None
        self._values_reference = None
        self._units = None
        self._file = None
        self._fill_value = None
        self._id = None
        self._uid = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if multiplier is not None:
            self.multiplier = multiplier
        if simulation is not None:
            self.simulation = simulation
        self.offset = offset
        self.duration = duration
        self.timestamps = timestamps
        self.interval = interval
        self.values_reference = values_reference
        self.units = units
        if file is not None:
            self.file = file
        if fill_value is not None:
            self.fill_value = fill_value
        if id is not None:
            self.id = id
        if uid is not None:
            self.uid = uid

    @property
    def url(self):
        """Gets the url of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The url of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this NetCDFTimeseriesSourcesSinks.


        :param url: The url of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def multiplier(self):
        """Gets the multiplier of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The multiplier of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: float
        """
        return self._multiplier

    @multiplier.setter
    def multiplier(self, multiplier):
        """Sets the multiplier of this NetCDFTimeseriesSourcesSinks.


        :param multiplier: The multiplier of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: float
        """

        self._multiplier = multiplier

    @property
    def simulation(self):
        """Gets the simulation of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The simulation of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._simulation

    @simulation.setter
    def simulation(self, simulation):
        """Sets the simulation of this NetCDFTimeseriesSourcesSinks.


        :param simulation: The simulation of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """

        self._simulation = simulation

    @property
    def offset(self):
        """Gets the offset of this NetCDFTimeseriesSourcesSinks.  # noqa: E501

        offset of event in simulation in seconds  # noqa: E501

        :return: The offset of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this NetCDFTimeseriesSourcesSinks.

        offset of event in simulation in seconds  # noqa: E501

        :param offset: The offset of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._offset = offset

    @property
    def duration(self):
        """Gets the duration of this NetCDFTimeseriesSourcesSinks.  # noqa: E501

        Duration of event in seconds  # noqa: E501

        :return: The duration of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this NetCDFTimeseriesSourcesSinks.

        Duration of event in seconds  # noqa: E501

        :param duration: The duration of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                duration is not None and duration > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `duration`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                duration is not None and duration < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `duration`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._duration = duration

    @property
    def timestamps(self):
        """Gets the timestamps of this NetCDFTimeseriesSourcesSinks.  # noqa: E501

        in simulation in seconds  # noqa: E501

        :return: The timestamps of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: list[int]
        """
        return self._timestamps

    @timestamps.setter
    def timestamps(self, timestamps):
        """Sets the timestamps of this NetCDFTimeseriesSourcesSinks.

        in simulation in seconds  # noqa: E501

        :param timestamps: The timestamps of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: list[int]
        """

        self._timestamps = timestamps

    @property
    def interval(self):
        """Gets the interval of this NetCDFTimeseriesSourcesSinks.  # noqa: E501

        interval in seconds  # noqa: E501

        :return: The interval of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this NetCDFTimeseriesSourcesSinks.

        interval in seconds  # noqa: E501

        :param interval: The interval of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                interval is not None and interval > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `interval`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                interval is not None and interval < 0):  # noqa: E501
            raise ValueError("Invalid value for `interval`, must be a value greater than or equal to `0`")  # noqa: E501

        self._interval = interval

    @property
    def values_reference(self):
        """Gets the values_reference of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The values_reference of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._values_reference

    @values_reference.setter
    def values_reference(self, values_reference):
        """Sets the values_reference of this NetCDFTimeseriesSourcesSinks.


        :param values_reference: The values_reference of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                values_reference is not None and len(values_reference) > 255):
            raise ValueError("Invalid value for `values_reference`, length must be less than or equal to `255`")  # noqa: E501

        self._values_reference = values_reference

    @property
    def units(self):
        """Gets the units of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The units of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this NetCDFTimeseriesSourcesSinks.


        :param units: The units of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and units is None:  # noqa: E501
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501
        allowed_values = ["mm", "mm/h"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and units not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `units` ({0}), must be one of {1}"  # noqa: E501
                .format(units, allowed_values)
            )

        self._units = units

    @property
    def file(self):
        """Gets the file of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The file of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: FileReadOnly
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this NetCDFTimeseriesSourcesSinks.


        :param file: The file of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: FileReadOnly
        """

        self._file = file

    @property
    def fill_value(self):
        """Gets the fill_value of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The fill_value of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._fill_value

    @fill_value.setter
    def fill_value(self, fill_value):
        """Sets the fill_value of this NetCDFTimeseriesSourcesSinks.


        :param fill_value: The fill_value of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fill_value is not None and len(fill_value) > 128):
            raise ValueError("Invalid value for `fill_value`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                fill_value is not None and len(fill_value) < 1):
            raise ValueError("Invalid value for `fill_value`, length must be greater than or equal to `1`")  # noqa: E501

        self._fill_value = fill_value

    @property
    def id(self):
        """Gets the id of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The id of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NetCDFTimeseriesSourcesSinks.


        :param id: The id of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def uid(self):
        """Gets the uid of this NetCDFTimeseriesSourcesSinks.  # noqa: E501


        :return: The uid of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this NetCDFTimeseriesSourcesSinks.


        :param uid: The uid of this NetCDFTimeseriesSourcesSinks.  # noqa: E501
        :type: str
        """

        self._uid = uid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetCDFTimeseriesSourcesSinks):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NetCDFTimeseriesSourcesSinks):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.0.28"

# import apis into sdk package
from openapi_client.api.auth_api import AuthApi
from openapi_client.api.contracts_api import ContractsApi
from openapi_client.api.files_api import FilesApi
from openapi_client.api.inpy_versions_api import InpyVersionsApi
from openapi_client.api.organisations_api import OrganisationsApi
from openapi_client.api.permissions_api import PermissionsApi
from openapi_client.api.repositories_api import RepositoriesApi
from openapi_client.api.revisions_api import RevisionsApi
from openapi_client.api.roles_api import RolesApi
from openapi_client.api.simulations_api import SimulationsApi
from openapi_client.api.statuses_api import StatusesApi
from openapi_client.api.threedimodels_api import ThreedimodelsApi
from openapi_client.api.usage_api import UsageApi

# import ApiClient
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.exceptions import OpenApiException
from openapi_client.exceptions import ApiTypeError
from openapi_client.exceptions import ApiValueError
from openapi_client.exceptions import ApiKeyError
from openapi_client.exceptions import ApiException
# import models into sdk package
from openapi_client.models.action import Action
from openapi_client.models.aggregation_settings import AggregationSettings
from openapi_client.models.arrival_time_post_processing import ArrivalTimePostProcessing
from openapi_client.models.authenticate import Authenticate
from openapi_client.models.base_event_state import BaseEventState
from openapi_client.models.basic_post_processing import BasicPostProcessing
from openapi_client.models.boundary_condition import BoundaryCondition
from openapi_client.models.breach import Breach
from openapi_client.models.breach_graph import BreachGraph
from openapi_client.models.breach_graph_request import BreachGraphRequest
from openapi_client.models.constant_lateral import ConstantLateral
from openapi_client.models.constant_leakage import ConstantLeakage
from openapi_client.models.constant_local_rain import ConstantLocalRain
from openapi_client.models.constant_rain import ConstantRain
from openapi_client.models.constant_sources_sinks import ConstantSourcesSinks
from openapi_client.models.constant_wind import ConstantWind
from openapi_client.models.contract import Contract
from openapi_client.models.current_status import CurrentStatus
from openapi_client.models.damage_estimation import DamageEstimation
from openapi_client.models.damage_post_processing import DamagePostProcessing
from openapi_client.models.download import Download
from openapi_client.models.event import Event
from openapi_client.models.extent import Extent
from openapi_client.models.file import File
from openapi_client.models.file_boundary_condition import FileBoundaryCondition
from openapi_client.models.file_lateral import FileLateral
from openapi_client.models.file_meta import FileMeta
from openapi_client.models.file_raster_leakage import FileRasterLeakage
from openapi_client.models.file_raster_rain import FileRasterRain
from openapi_client.models.file_raster_sources_sinks import FileRasterSourcesSinks
from openapi_client.models.file_read_only import FileReadOnly
from openapi_client.models.file_timeseries_leakage import FileTimeseriesLeakage
from openapi_client.models.file_timeseries_rain import FileTimeseriesRain
from openapi_client.models.file_timeseries_sources_sinks import FileTimeseriesSourcesSinks
from openapi_client.models.grid_event_state import GridEventState
from openapi_client.models.ground_water_level import GroundWaterLevel
from openapi_client.models.ground_water_raster import GroundWaterRaster
from openapi_client.models.initial_saved_state import InitialSavedState
from openapi_client.models.initial_saved_state_overview import InitialSavedStateOverview
from openapi_client.models.initial_waterlevel import InitialWaterlevel
from openapi_client.models.inline_response200 import InlineResponse200
from openapi_client.models.inline_response2001 import InlineResponse2001
from openapi_client.models.inline_response20010 import InlineResponse20010
from openapi_client.models.inline_response20011 import InlineResponse20011
from openapi_client.models.inline_response20012 import InlineResponse20012
from openapi_client.models.inline_response20013 import InlineResponse20013
from openapi_client.models.inline_response20014 import InlineResponse20014
from openapi_client.models.inline_response20015 import InlineResponse20015
from openapi_client.models.inline_response20016 import InlineResponse20016
from openapi_client.models.inline_response20017 import InlineResponse20017
from openapi_client.models.inline_response20018 import InlineResponse20018
from openapi_client.models.inline_response20019 import InlineResponse20019
from openapi_client.models.inline_response2002 import InlineResponse2002
from openapi_client.models.inline_response20020 import InlineResponse20020
from openapi_client.models.inline_response20021 import InlineResponse20021
from openapi_client.models.inline_response20022 import InlineResponse20022
from openapi_client.models.inline_response20023 import InlineResponse20023
from openapi_client.models.inline_response20024 import InlineResponse20024
from openapi_client.models.inline_response20025 import InlineResponse20025
from openapi_client.models.inline_response20026 import InlineResponse20026
from openapi_client.models.inline_response20027 import InlineResponse20027
from openapi_client.models.inline_response20028 import InlineResponse20028
from openapi_client.models.inline_response20029 import InlineResponse20029
from openapi_client.models.inline_response2003 import InlineResponse2003
from openapi_client.models.inline_response20030 import InlineResponse20030
from openapi_client.models.inline_response20031 import InlineResponse20031
from openapi_client.models.inline_response20032 import InlineResponse20032
from openapi_client.models.inline_response20033 import InlineResponse20033
from openapi_client.models.inline_response20034 import InlineResponse20034
from openapi_client.models.inline_response20035 import InlineResponse20035
from openapi_client.models.inline_response20036 import InlineResponse20036
from openapi_client.models.inline_response20037 import InlineResponse20037
from openapi_client.models.inline_response20038 import InlineResponse20038
from openapi_client.models.inline_response20039 import InlineResponse20039
from openapi_client.models.inline_response2004 import InlineResponse2004
from openapi_client.models.inline_response20040 import InlineResponse20040
from openapi_client.models.inline_response20041 import InlineResponse20041
from openapi_client.models.inline_response20042 import InlineResponse20042
from openapi_client.models.inline_response20043 import InlineResponse20043
from openapi_client.models.inline_response20044 import InlineResponse20044
from openapi_client.models.inline_response20045 import InlineResponse20045
from openapi_client.models.inline_response20046 import InlineResponse20046
from openapi_client.models.inline_response20047 import InlineResponse20047
from openapi_client.models.inline_response20048 import InlineResponse20048
from openapi_client.models.inline_response20049 import InlineResponse20049
from openapi_client.models.inline_response2005 import InlineResponse2005
from openapi_client.models.inline_response20050 import InlineResponse20050
from openapi_client.models.inline_response20051 import InlineResponse20051
from openapi_client.models.inline_response20052 import InlineResponse20052
from openapi_client.models.inline_response20053 import InlineResponse20053
from openapi_client.models.inline_response20054 import InlineResponse20054
from openapi_client.models.inline_response20055 import InlineResponse20055
from openapi_client.models.inline_response20056 import InlineResponse20056
from openapi_client.models.inline_response20057 import InlineResponse20057
from openapi_client.models.inline_response20058 import InlineResponse20058
from openapi_client.models.inline_response20059 import InlineResponse20059
from openapi_client.models.inline_response2006 import InlineResponse2006
from openapi_client.models.inline_response20060 import InlineResponse20060
from openapi_client.models.inline_response20061 import InlineResponse20061
from openapi_client.models.inline_response2007 import InlineResponse2007
from openapi_client.models.inline_response2008 import InlineResponse2008
from openapi_client.models.inline_response2009 import InlineResponse2009
from openapi_client.models.inpy_version import InpyVersion
from openapi_client.models.lateral import Lateral
from openapi_client.models.linestring import Linestring
from openapi_client.models.lizard_raster_rain import LizardRasterRain
from openapi_client.models.lizard_raster_sources_sinks import LizardRasterSourcesSinks
from openapi_client.models.lizard_timeseries_rain import LizardTimeseriesRain
from openapi_client.models.lizard_timeseries_sources_sinks import LizardTimeseriesSourcesSinks
from openapi_client.models.local_rain import LocalRain
from openapi_client.models.measure_location import MeasureLocation
from openapi_client.models.measure_location_grid_event_state import MeasureLocationGridEventState
from openapi_client.models.measure_specification import MeasureSpecification
from openapi_client.models.memory_structure_control import MemoryStructureControl
from openapi_client.models.net_cdf_raster_leakage import NetCDFRasterLeakage
from openapi_client.models.net_cdf_raster_rain import NetCDFRasterRain
from openapi_client.models.net_cdf_raster_sources_sinks import NetCDFRasterSourcesSinks
from openapi_client.models.net_cdf_timeseries_leakage import NetCDFTimeseriesLeakage
from openapi_client.models.net_cdf_timeseries_rain import NetCDFTimeseriesRain
from openapi_client.models.net_cdf_timeseries_sources_sinks import NetCDFTimeseriesSourcesSinks
from openapi_client.models.numerical_settings import NumericalSettings
from openapi_client.models.one_d_water_level import OneDWaterLevel
from openapi_client.models.one_d_water_level_predefined import OneDWaterLevelPredefined
from openapi_client.models.organisation import Organisation
from openapi_client.models.organisation_role import OrganisationRole
from openapi_client.models.physical_settings import PhysicalSettings
from openapi_client.models.point import Point
from openapi_client.models.polygon import Polygon
from openapi_client.models.post_processing_overview import PostProcessingOverview
from openapi_client.models.post_processing_queue import PostProcessingQueue
from openapi_client.models.post_processing_status import PostProcessingStatus
from openapi_client.models.potential_breach import PotentialBreach
from openapi_client.models.profile import Profile
from openapi_client.models.progress import Progress
from openapi_client.models.pump_discharge_graph import PumpDischargeGraph
from openapi_client.models.pump_discharge_graph_request import PumpDischargeGraphRequest
from openapi_client.models.raster import Raster
from openapi_client.models.raster_edit import RasterEdit
from openapi_client.models.raster_edit_urls import RasterEditUrls
from openapi_client.models.raster_options import RasterOptions
from openapi_client.models.refresh import Refresh
from openapi_client.models.repository import Repository
from openapi_client.models.result import Result
from openapi_client.models.result_file import ResultFile
from openapi_client.models.revision import Revision
from openapi_client.models.role import Role
from openapi_client.models.saved_state_overview import SavedStateOverview
from openapi_client.models.settings import Settings
from openapi_client.models.simulation import Simulation
from openapi_client.models.simulation_channel import SimulationChannel
from openapi_client.models.simulation_settings_overview import SimulationSettingsOverview
from openapi_client.models.simulation_status import SimulationStatus
from openapi_client.models.simulation_status_statistics import SimulationStatusStatistics
from openapi_client.models.simulation_update import SimulationUpdate
from openapi_client.models.stable_threshold_saved_state import StableThresholdSavedState
from openapi_client.models.tms import TMS
from openapi_client.models.table_structure_control import TableStructureControl
from openapi_client.models.threedi_model import ThreediModel
from openapi_client.models.threedi_model_saved_state import ThreediModelSavedState
from openapi_client.models.threshold import Threshold
from openapi_client.models.time_step_settings import TimeStepSettings
from openapi_client.models.timed_saved_state_update import TimedSavedStateUpdate
from openapi_client.models.timed_structure_control import TimedStructureControl
from openapi_client.models.timeout import Timeout
from openapi_client.models.timeseries_lateral import TimeseriesLateral
from openapi_client.models.timeseries_leakage import TimeseriesLeakage
from openapi_client.models.timeseries_leakage_overview import TimeseriesLeakageOverview
from openapi_client.models.timeseries_local_rain import TimeseriesLocalRain
from openapi_client.models.timeseries_rain import TimeseriesRain
from openapi_client.models.timeseries_rain_overview import TimeseriesRainOverview
from openapi_client.models.timeseries_sources_sinks import TimeseriesSourcesSinks
from openapi_client.models.timeseries_sources_sinks_overview import TimeseriesSourcesSinksOverview
from openapi_client.models.timeseries_wind import TimeseriesWind
from openapi_client.models.tokens import Tokens
from openapi_client.models.two_d_water_level import TwoDWaterLevel
from openapi_client.models.two_d_water_raster import TwoDWaterRaster
from openapi_client.models.upload import Upload
from openapi_client.models.upload_event_file import UploadEventFile
from openapi_client.models.usage import Usage
from openapi_client.models.usage_statistics import UsageStatistics
from openapi_client.models.user import User
from openapi_client.models.water_flow_graph_request import WaterFlowGraphRequest
from openapi_client.models.water_graph import WaterGraph
from openapi_client.models.water_level_graph_request import WaterLevelGraphRequest
from openapi_client.models.water_level_profile import WaterLevelProfile
from openapi_client.models.water_level_profile_request import WaterLevelProfileRequest
from openapi_client.models.waterdepth import Waterdepth
from openapi_client.models.wind import Wind
from openapi_client.models.wind_drag_coefficient import WindDragCoefficient




# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class BoundaryCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'url': 'str',
        'boundary_id': 'int',
        'threedimodel': 'str',
        'type': 'str',
        'dimension': 'str'
    }

    attribute_map = {
        'id': 'id',
        'url': 'url',
        'boundary_id': 'boundary_id',
        'threedimodel': 'threedimodel',
        'type': 'type',
        'dimension': 'dimension'
    }

    def __init__(self, id=None, url=None, boundary_id=None, threedimodel=None, type=None, dimension=None, local_vars_configuration=None):  # noqa: E501
        """BoundaryCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._url = None
        self._boundary_id = None
        self._threedimodel = None
        self._type = None
        self._dimension = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if url is not None:
            self.url = url
        self.boundary_id = boundary_id
        if threedimodel is not None:
            self.threedimodel = threedimodel
        self.type = type
        self.dimension = dimension

    @property
    def id(self):
        """Gets the id of this BoundaryCondition.  # noqa: E501


        :return: The id of this BoundaryCondition.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BoundaryCondition.


        :param id: The id of this BoundaryCondition.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def url(self):
        """Gets the url of this BoundaryCondition.  # noqa: E501


        :return: The url of this BoundaryCondition.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this BoundaryCondition.


        :param url: The url of this BoundaryCondition.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def boundary_id(self):
        """Gets the boundary_id of this BoundaryCondition.  # noqa: E501


        :return: The boundary_id of this BoundaryCondition.  # noqa: E501
        :rtype: int
        """
        return self._boundary_id

    @boundary_id.setter
    def boundary_id(self, boundary_id):
        """Sets the boundary_id of this BoundaryCondition.


        :param boundary_id: The boundary_id of this BoundaryCondition.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and boundary_id is None:  # noqa: E501
            raise ValueError("Invalid value for `boundary_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                boundary_id is not None and boundary_id > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `boundary_id`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                boundary_id is not None and boundary_id < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `boundary_id`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._boundary_id = boundary_id

    @property
    def threedimodel(self):
        """Gets the threedimodel of this BoundaryCondition.  # noqa: E501


        :return: The threedimodel of this BoundaryCondition.  # noqa: E501
        :rtype: str
        """
        return self._threedimodel

    @threedimodel.setter
    def threedimodel(self, threedimodel):
        """Sets the threedimodel of this BoundaryCondition.


        :param threedimodel: The threedimodel of this BoundaryCondition.  # noqa: E501
        :type: str
        """

        self._threedimodel = threedimodel

    @property
    def type(self):
        """Gets the type of this BoundaryCondition.  # noqa: E501


        :return: The type of this BoundaryCondition.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BoundaryCondition.


        :param type: The type of this BoundaryCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["velocity", "sommerfeldt", "riemann", "water_level", "discharge"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def dimension(self):
        """Gets the dimension of this BoundaryCondition.  # noqa: E501


        :return: The dimension of this BoundaryCondition.  # noqa: E501
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """Sets the dimension of this BoundaryCondition.


        :param dimension: The dimension of this BoundaryCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and dimension is None:  # noqa: E501
            raise ValueError("Invalid value for `dimension`, must not be `None`")  # noqa: E501
        allowed_values = ["one_d", "two_d"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and dimension not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `dimension` ({0}), must be one of {1}"  # noqa: E501
                .format(dimension, allowed_values)
            )

        self._dimension = dimension

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BoundaryCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BoundaryCondition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class FileReadOnly(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'filename': 'str',
        'state': 'str',
        'state_description': 'str',
        'type': 'str',
        'size': 'int',
        'etag': 'str',
        'expiry_date': 'date',
        'id': 'int'
    }

    attribute_map = {
        'url': 'url',
        'filename': 'filename',
        'state': 'state',
        'state_description': 'state_description',
        'type': 'type',
        'size': 'size',
        'etag': 'etag',
        'expiry_date': 'expiry_date',
        'id': 'id'
    }

    def __init__(self, url=None, filename=None, state=None, state_description=None, type=None, size=None, etag=None, expiry_date=None, id=None, local_vars_configuration=None):  # noqa: E501
        """FileReadOnly - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._filename = None
        self._state = None
        self._state_description = None
        self._type = None
        self._size = None
        self._etag = None
        self._expiry_date = None
        self._id = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if filename is not None:
            self.filename = filename
        if state is not None:
            self.state = state
        self.state_description = state_description
        if type is not None:
            self.type = type
        if size is not None:
            self.size = size
        self.etag = etag
        if expiry_date is not None:
            self.expiry_date = expiry_date
        if id is not None:
            self.id = id

    @property
    def url(self):
        """Gets the url of this FileReadOnly.  # noqa: E501


        :return: The url of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this FileReadOnly.


        :param url: The url of this FileReadOnly.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def filename(self):
        """Gets the filename of this FileReadOnly.  # noqa: E501


        :return: The filename of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this FileReadOnly.


        :param filename: The filename of this FileReadOnly.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                filename is not None and len(filename) < 1):
            raise ValueError("Invalid value for `filename`, length must be greater than or equal to `1`")  # noqa: E501

        self._filename = filename

    @property
    def state(self):
        """Gets the state of this FileReadOnly.  # noqa: E501


        :return: The state of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this FileReadOnly.


        :param state: The state of this FileReadOnly.  # noqa: E501
        :type: str
        """
        allowed_values = ["created", "uploaded", "processed", "error", "removed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def state_description(self):
        """Gets the state_description of this FileReadOnly.  # noqa: E501


        :return: The state_description of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._state_description

    @state_description.setter
    def state_description(self, state_description):
        """Sets the state_description of this FileReadOnly.


        :param state_description: The state_description of this FileReadOnly.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                state_description is not None and len(state_description) > 512):
            raise ValueError("Invalid value for `state_description`, length must be less than or equal to `512`")  # noqa: E501

        self._state_description = state_description

    @property
    def type(self):
        """Gets the type of this FileReadOnly.  # noqa: E501


        :return: The type of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FileReadOnly.


        :param type: The type of this FileReadOnly.  # noqa: E501
        :type: str
        """
        allowed_values = ["timeseries", "rastertimeseries", "savedstate", "results", "rasters", "gridadmin", "geojson", "initialwaterlevel", "bulklateral", "bulk_boundaryconditions"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def size(self):
        """Gets the size of this FileReadOnly.  # noqa: E501

        Filesize in bytes  # noqa: E501

        :return: The size of this FileReadOnly.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FileReadOnly.

        Filesize in bytes  # noqa: E501

        :param size: The size of this FileReadOnly.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def etag(self):
        """Gets the etag of this FileReadOnly.  # noqa: E501

        Optional eTag (md5sum)  # noqa: E501

        :return: The etag of this FileReadOnly.  # noqa: E501
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """Sets the etag of this FileReadOnly.

        Optional eTag (md5sum)  # noqa: E501

        :param etag: The etag of this FileReadOnly.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                etag is not None and len(etag) > 256):
            raise ValueError("Invalid value for `etag`, length must be less than or equal to `256`")  # noqa: E501

        self._etag = etag

    @property
    def expiry_date(self):
        """Gets the expiry_date of this FileReadOnly.  # noqa: E501


        :return: The expiry_date of this FileReadOnly.  # noqa: E501
        :rtype: date
        """
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, expiry_date):
        """Sets the expiry_date of this FileReadOnly.


        :param expiry_date: The expiry_date of this FileReadOnly.  # noqa: E501
        :type: date
        """

        self._expiry_date = expiry_date

    @property
    def id(self):
        """Gets the id of this FileReadOnly.  # noqa: E501


        :return: The id of this FileReadOnly.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileReadOnly.


        :param id: The id of this FileReadOnly.  # noqa: E501
        :type: int
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileReadOnly):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileReadOnly):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class MeasureLocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'weight': 'str',
        'content_type': 'str',
        'content_pk': 'int',
        'grid_id': 'int',
        'state': 'str',
        'state_detail': 'object'
    }

    attribute_map = {
        'id': 'id',
        'weight': 'weight',
        'content_type': 'content_type',
        'content_pk': 'content_pk',
        'grid_id': 'grid_id',
        'state': 'state',
        'state_detail': 'state_detail'
    }

    def __init__(self, id=None, weight=None, content_type=None, content_pk=None, grid_id=None, state=None, state_detail=None, local_vars_configuration=None):  # noqa: E501
        """MeasureLocation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._weight = None
        self._content_type = None
        self._content_pk = None
        self._grid_id = None
        self._state = None
        self._state_detail = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.weight = weight
        self.content_type = content_type
        self.content_pk = content_pk
        self.grid_id = grid_id
        if state is not None:
            self.state = state
        if state_detail is not None:
            self.state_detail = state_detail

    @property
    def id(self):
        """Gets the id of this MeasureLocation.  # noqa: E501


        :return: The id of this MeasureLocation.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MeasureLocation.


        :param id: The id of this MeasureLocation.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def weight(self):
        """Gets the weight of this MeasureLocation.  # noqa: E501


        :return: The weight of this MeasureLocation.  # noqa: E501
        :rtype: str
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this MeasureLocation.


        :param weight: The weight of this MeasureLocation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and weight is None:  # noqa: E501
            raise ValueError("Invalid value for `weight`, must not be `None`")  # noqa: E501

        self._weight = weight

    @property
    def content_type(self):
        """Gets the content_type of this MeasureLocation.  # noqa: E501

        e.g.   # noqa: E501

        :return: The content_type of this MeasureLocation.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this MeasureLocation.

        e.g.   # noqa: E501

        :param content_type: The content_type of this MeasureLocation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and content_type is None:  # noqa: E501
            raise ValueError("Invalid value for `content_type`, must not be `None`")  # noqa: E501
        allowed_values = ["v2_connection_node", "v2_pipe", "v2_orifice", "v2_culvert", "v2_channel", "v2_weir"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and content_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `content_type` ({0}), must be one of {1}"  # noqa: E501
                .format(content_type, allowed_values)
            )

        self._content_type = content_type

    @property
    def content_pk(self):
        """Gets the content_pk of this MeasureLocation.  # noqa: E501


        :return: The content_pk of this MeasureLocation.  # noqa: E501
        :rtype: int
        """
        return self._content_pk

    @content_pk.setter
    def content_pk(self, content_pk):
        """Sets the content_pk of this MeasureLocation.


        :param content_pk: The content_pk of this MeasureLocation.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and content_pk is None:  # noqa: E501
            raise ValueError("Invalid value for `content_pk`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                content_pk is not None and content_pk > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `content_pk`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                content_pk is not None and content_pk < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `content_pk`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._content_pk = content_pk

    @property
    def grid_id(self):
        """Gets the grid_id of this MeasureLocation.  # noqa: E501


        :return: The grid_id of this MeasureLocation.  # noqa: E501
        :rtype: int
        """
        return self._grid_id

    @grid_id.setter
    def grid_id(self, grid_id):
        """Sets the grid_id of this MeasureLocation.


        :param grid_id: The grid_id of this MeasureLocation.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                grid_id is not None and grid_id > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `grid_id`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                grid_id is not None and grid_id < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `grid_id`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._grid_id = grid_id

    @property
    def state(self):
        """Gets the state of this MeasureLocation.  # noqa: E501


        :return: The state of this MeasureLocation.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this MeasureLocation.


        :param state: The state of this MeasureLocation.  # noqa: E501
        :type: str
        """
        allowed_values = ["processing", "valid", "invalid"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def state_detail(self):
        """Gets the state_detail of this MeasureLocation.  # noqa: E501


        :return: The state_detail of this MeasureLocation.  # noqa: E501
        :rtype: object
        """
        return self._state_detail

    @state_detail.setter
    def state_detail(self, state_detail):
        """Sets the state_detail of this MeasureLocation.


        :param state_detail: The state_detail of this MeasureLocation.  # noqa: E501
        :type: object
        """

        self._state_detail = state_detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MeasureLocation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MeasureLocation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class Usage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'simulation': 'Simulation',
        'started': 'datetime',
        'finished': 'datetime',
        'total_time': 'int',
        'status': 'str',
        'simulation_type': 'str',
        'user_name': 'str',
        'organisation_uuid': 'str'
    }

    attribute_map = {
        'id': 'id',
        'simulation': 'simulation',
        'started': 'started',
        'finished': 'finished',
        'total_time': 'total_time',
        'status': 'status',
        'simulation_type': 'simulation_type',
        'user_name': 'user_name',
        'organisation_uuid': 'organisation_uuid'
    }

    def __init__(self, id=None, simulation=None, started=None, finished=None, total_time=None, status=None, simulation_type=None, user_name=None, organisation_uuid=None, local_vars_configuration=None):  # noqa: E501
        """Usage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._simulation = None
        self._started = None
        self._finished = None
        self._total_time = None
        self._status = None
        self._simulation_type = None
        self._user_name = None
        self._organisation_uuid = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if simulation is not None:
            self.simulation = simulation
        self.started = started
        self.finished = finished
        self.total_time = total_time
        if status is not None:
            self.status = status
        if simulation_type is not None:
            self.simulation_type = simulation_type
        if user_name is not None:
            self.user_name = user_name
        if organisation_uuid is not None:
            self.organisation_uuid = organisation_uuid

    @property
    def id(self):
        """Gets the id of this Usage.  # noqa: E501


        :return: The id of this Usage.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Usage.


        :param id: The id of this Usage.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def simulation(self):
        """Gets the simulation of this Usage.  # noqa: E501


        :return: The simulation of this Usage.  # noqa: E501
        :rtype: Simulation
        """
        return self._simulation

    @simulation.setter
    def simulation(self, simulation):
        """Sets the simulation of this Usage.


        :param simulation: The simulation of this Usage.  # noqa: E501
        :type: Simulation
        """

        self._simulation = simulation

    @property
    def started(self):
        """Gets the started of this Usage.  # noqa: E501


        :return: The started of this Usage.  # noqa: E501
        :rtype: datetime
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this Usage.


        :param started: The started of this Usage.  # noqa: E501
        :type: datetime
        """

        self._started = started

    @property
    def finished(self):
        """Gets the finished of this Usage.  # noqa: E501


        :return: The finished of this Usage.  # noqa: E501
        :rtype: datetime
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this Usage.


        :param finished: The finished of this Usage.  # noqa: E501
        :type: datetime
        """

        self._finished = finished

    @property
    def total_time(self):
        """Gets the total_time of this Usage.  # noqa: E501


        :return: The total_time of this Usage.  # noqa: E501
        :rtype: int
        """
        return self._total_time

    @total_time.setter
    def total_time(self, total_time):
        """Sets the total_time of this Usage.


        :param total_time: The total_time of this Usage.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                total_time is not None and total_time > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `total_time`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                total_time is not None and total_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `total_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_time = total_time

    @property
    def status(self):
        """Gets the status of this Usage.  # noqa: E501


        :return: The status of this Usage.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Usage.


        :param status: The status of this Usage.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def simulation_type(self):
        """Gets the simulation_type of this Usage.  # noqa: E501


        :return: The simulation_type of this Usage.  # noqa: E501
        :rtype: str
        """
        return self._simulation_type

    @simulation_type.setter
    def simulation_type(self, simulation_type):
        """Sets the simulation_type of this Usage.


        :param simulation_type: The simulation_type of this Usage.  # noqa: E501
        :type: str
        """

        self._simulation_type = simulation_type

    @property
    def user_name(self):
        """Gets the user_name of this Usage.  # noqa: E501


        :return: The user_name of this Usage.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this Usage.


        :param user_name: The user_name of this Usage.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def organisation_uuid(self):
        """Gets the organisation_uuid of this Usage.  # noqa: E501


        :return: The organisation_uuid of this Usage.  # noqa: E501
        :rtype: str
        """
        return self._organisation_uuid

    @organisation_uuid.setter
    def organisation_uuid(self, organisation_uuid):
        """Sets the organisation_uuid of this Usage.


        :param organisation_uuid: The organisation_uuid of this Usage.  # noqa: E501
        :type: str
        """

        self._organisation_uuid = organisation_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Usage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Usage):
            return True

        return self.to_dict() != other.to_dict()



import jwt
from datetime import datetime, timedelta
from openapi_client import ApiClient
from openapi_client import Configuration
from openapi_client import AuthApi
from openapi_client.models import Authenticate

from threedi_api_client.config import Config, EnvironConfig

# Get new token REFRESH_TIME_DELTA before it really expires.
REFRESH_TIME_DELTA = timedelta(hours=4).total_seconds()


def get_auth_token(username: str, password: str, api_host: str):
    api_client = ApiClient(
        Configuration(
            username=username,
            password=password,
            host=api_host
        )
    )
    auth = AuthApi(api_client)
    return auth.auth_token_create(Authenticate(username, password))


def is_token_usable(token: str) -> bool:
    if token is None:
        return False

    try:
        # Get payload without verifying signature,
        # does NOT validate claims (including exp)
        payload = jwt.decode(
            token,
            options={"verify_signature": False},
        )
    except (jwt.exceptions.ExpiredSignatureError, jwt.exceptions.DecodeError):
        return False

    expiry_dt = datetime.utcfromtimestamp(payload["exp"])
    sec_left = (expiry_dt - datetime.utcnow()).total_seconds()
    return sec_left >= REFRESH_TIME_DELTA


def refresh_api_key(config: Configuration):
    """Refreshes the access key if its expired"""
    api_key = config.api_key.get("Authorization")
    if is_token_usable(api_key):
        return

    refresh_key = config.api_key['refresh']
    if is_token_usable(refresh_key):
        api_client = ApiClient(Configuration(config.host))
        auth = AuthApi(api_client)
        token = auth.auth_refresh_token_create(
            {"refresh": config.api_key['refresh']}
        )
    else:
        token = get_auth_token(config.username, config.password, config.host)
    config.api_key = {
        'Authorization': token.access,
        'refresh': token.refresh
    }


class ThreediApiClient:
    def __new__(cls, env_file=None, config=None):
        if env_file is not None:
            user_config = Config(env_file)
        elif config is not None:
            user_config = config
        else:
            user_config = EnvironConfig()

        configuration = Configuration(
            host=user_config.get("API_HOST"),
            username=user_config.get("API_USERNAME"),
            password=user_config.get("API_PASSWORD"),
            api_key={"Authorization": '', "refresh": ''},
            api_key_prefix={"Authorization": "Bearer"}
        )
        configuration.refresh_api_key_hook = refresh_api_key
        api_client = ApiClient(configuration)
        return api_client



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class Event(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'lizardrasterrain': 'list[LizardRasterRain]',
        'lizardtimeseriesrain': 'list[LizardTimeseriesRain]',
        'timeseriesrain': 'list[TimeseriesRainOverview]',
        'breach': 'list[Breach]',
        'lizardrastersourcessinks': 'list[LizardRasterSourcesSinks]',
        'lizardtimeseriessourcessinks': 'list[LizardTimeseriesSourcesSinks]',
        'filerastersourcessinks': 'list[FileRasterSourcesSinks]',
        'filetimeseriessourcessinks': 'list[FileTimeseriesSourcesSinks]',
        'timeseriessourcessinks': 'list[TimeseriesSourcesSinksOverview]',
        'leakage': 'list[TimeseriesLeakageOverview]',
        'filetimeseriesleakage': 'list[FileTimeseriesLeakage]',
        'filerasterleakage': 'list[FileRasterLeakage]',
        'initial_twodwaterlevel': 'TwoDWaterLevel',
        'initial_onedwaterlevelpredefined': 'OneDWaterLevelPredefined',
        'initial_groundwaterlevel': 'GroundWaterLevel',
        'initial_groundwaterraster': 'GroundWaterRaster',
        'initial_onedwaterlevel': 'OneDWaterLevel',
        'initial_twodwaterraster': 'TwoDWaterRaster',
        'filerasterrain': 'list[FileRasterRain]',
        'filetimeseriesrain': 'list[FileTimeseriesRain]',
        'initial_savedstate': 'InitialSavedStateOverview',
        'savedstates': 'list[SavedStateOverview]',
        'laterals': 'list[Lateral]',
        'filelaterals': 'list[FileLateral]',
        'fileboundaryconditions': 'FileBoundaryCondition',
        'tablestructurecontrols': 'list[TableStructureControl]',
        'memorystructurecontrols': 'list[MemoryStructureControl]',
        'timedstructurecontrols': 'list[TimedStructureControl]',
        'rasteredits': 'list[RasterEdit]',
        'localrain': 'list[LocalRain]',
        'wind': 'list[Wind]',
        'initial_winddragcoefficient': 'WindDragCoefficient'
    }

    attribute_map = {
        'lizardrasterrain': 'lizardrasterrain',
        'lizardtimeseriesrain': 'lizardtimeseriesrain',
        'timeseriesrain': 'timeseriesrain',
        'breach': 'breach',
        'lizardrastersourcessinks': 'lizardrastersourcessinks',
        'lizardtimeseriessourcessinks': 'lizardtimeseriessourcessinks',
        'filerastersourcessinks': 'filerastersourcessinks',
        'filetimeseriessourcessinks': 'filetimeseriessourcessinks',
        'timeseriessourcessinks': 'timeseriessourcessinks',
        'leakage': 'leakage',
        'filetimeseriesleakage': 'filetimeseriesleakage',
        'filerasterleakage': 'filerasterleakage',
        'initial_twodwaterlevel': 'initial_twodwaterlevel',
        'initial_onedwaterlevelpredefined': 'initial_onedwaterlevelpredefined',
        'initial_groundwaterlevel': 'initial_groundwaterlevel',
        'initial_groundwaterraster': 'initial_groundwaterraster',
        'initial_onedwaterlevel': 'initial_onedwaterlevel',
        'initial_twodwaterraster': 'initial_twodwaterraster',
        'filerasterrain': 'filerasterrain',
        'filetimeseriesrain': 'filetimeseriesrain',
        'initial_savedstate': 'initial_savedstate',
        'savedstates': 'savedstates',
        'laterals': 'laterals',
        'filelaterals': 'filelaterals',
        'fileboundaryconditions': 'fileboundaryconditions',
        'tablestructurecontrols': 'tablestructurecontrols',
        'memorystructurecontrols': 'memorystructurecontrols',
        'timedstructurecontrols': 'timedstructurecontrols',
        'rasteredits': 'rasteredits',
        'localrain': 'localrain',
        'wind': 'wind',
        'initial_winddragcoefficient': 'initial_winddragcoefficient'
    }

    def __init__(self, lizardrasterrain=None, lizardtimeseriesrain=None, timeseriesrain=None, breach=None, lizardrastersourcessinks=None, lizardtimeseriessourcessinks=None, filerastersourcessinks=None, filetimeseriessourcessinks=None, timeseriessourcessinks=None, leakage=None, filetimeseriesleakage=None, filerasterleakage=None, initial_twodwaterlevel=None, initial_onedwaterlevelpredefined=None, initial_groundwaterlevel=None, initial_groundwaterraster=None, initial_onedwaterlevel=None, initial_twodwaterraster=None, filerasterrain=None, filetimeseriesrain=None, initial_savedstate=None, savedstates=None, laterals=None, filelaterals=None, fileboundaryconditions=None, tablestructurecontrols=None, memorystructurecontrols=None, timedstructurecontrols=None, rasteredits=None, localrain=None, wind=None, initial_winddragcoefficient=None, local_vars_configuration=None):  # noqa: E501
        """Event - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._lizardrasterrain = None
        self._lizardtimeseriesrain = None
        self._timeseriesrain = None
        self._breach = None
        self._lizardrastersourcessinks = None
        self._lizardtimeseriessourcessinks = None
        self._filerastersourcessinks = None
        self._filetimeseriessourcessinks = None
        self._timeseriessourcessinks = None
        self._leakage = None
        self._filetimeseriesleakage = None
        self._filerasterleakage = None
        self._initial_twodwaterlevel = None
        self._initial_onedwaterlevelpredefined = None
        self._initial_groundwaterlevel = None
        self._initial_groundwaterraster = None
        self._initial_onedwaterlevel = None
        self._initial_twodwaterraster = None
        self._filerasterrain = None
        self._filetimeseriesrain = None
        self._initial_savedstate = None
        self._savedstates = None
        self._laterals = None
        self._filelaterals = None
        self._fileboundaryconditions = None
        self._tablestructurecontrols = None
        self._memorystructurecontrols = None
        self._timedstructurecontrols = None
        self._rasteredits = None
        self._localrain = None
        self._wind = None
        self._initial_winddragcoefficient = None
        self.discriminator = None

        if lizardrasterrain is not None:
            self.lizardrasterrain = lizardrasterrain
        if lizardtimeseriesrain is not None:
            self.lizardtimeseriesrain = lizardtimeseriesrain
        if timeseriesrain is not None:
            self.timeseriesrain = timeseriesrain
        if breach is not None:
            self.breach = breach
        if lizardrastersourcessinks is not None:
            self.lizardrastersourcessinks = lizardrastersourcessinks
        if lizardtimeseriessourcessinks is not None:
            self.lizardtimeseriessourcessinks = lizardtimeseriessourcessinks
        if filerastersourcessinks is not None:
            self.filerastersourcessinks = filerastersourcessinks
        if filetimeseriessourcessinks is not None:
            self.filetimeseriessourcessinks = filetimeseriessourcessinks
        if timeseriessourcessinks is not None:
            self.timeseriessourcessinks = timeseriessourcessinks
        if leakage is not None:
            self.leakage = leakage
        if filetimeseriesleakage is not None:
            self.filetimeseriesleakage = filetimeseriesleakage
        if filerasterleakage is not None:
            self.filerasterleakage = filerasterleakage
        if initial_twodwaterlevel is not None:
            self.initial_twodwaterlevel = initial_twodwaterlevel
        if initial_onedwaterlevelpredefined is not None:
            self.initial_onedwaterlevelpredefined = initial_onedwaterlevelpredefined
        if initial_groundwaterlevel is not None:
            self.initial_groundwaterlevel = initial_groundwaterlevel
        if initial_groundwaterraster is not None:
            self.initial_groundwaterraster = initial_groundwaterraster
        if initial_onedwaterlevel is not None:
            self.initial_onedwaterlevel = initial_onedwaterlevel
        if initial_twodwaterraster is not None:
            self.initial_twodwaterraster = initial_twodwaterraster
        if filerasterrain is not None:
            self.filerasterrain = filerasterrain
        if filetimeseriesrain is not None:
            self.filetimeseriesrain = filetimeseriesrain
        if initial_savedstate is not None:
            self.initial_savedstate = initial_savedstate
        if savedstates is not None:
            self.savedstates = savedstates
        if laterals is not None:
            self.laterals = laterals
        if filelaterals is not None:
            self.filelaterals = filelaterals
        if fileboundaryconditions is not None:
            self.fileboundaryconditions = fileboundaryconditions
        if tablestructurecontrols is not None:
            self.tablestructurecontrols = tablestructurecontrols
        if memorystructurecontrols is not None:
            self.memorystructurecontrols = memorystructurecontrols
        if timedstructurecontrols is not None:
            self.timedstructurecontrols = timedstructurecontrols
        if rasteredits is not None:
            self.rasteredits = rasteredits
        if localrain is not None:
            self.localrain = localrain
        if wind is not None:
            self.wind = wind
        if initial_winddragcoefficient is not None:
            self.initial_winddragcoefficient = initial_winddragcoefficient

    @property
    def lizardrasterrain(self):
        """Gets the lizardrasterrain of this Event.  # noqa: E501


        :return: The lizardrasterrain of this Event.  # noqa: E501
        :rtype: list[LizardRasterRain]
        """
        return self._lizardrasterrain

    @lizardrasterrain.setter
    def lizardrasterrain(self, lizardrasterrain):
        """Sets the lizardrasterrain of this Event.


        :param lizardrasterrain: The lizardrasterrain of this Event.  # noqa: E501
        :type: list[LizardRasterRain]
        """

        self._lizardrasterrain = lizardrasterrain

    @property
    def lizardtimeseriesrain(self):
        """Gets the lizardtimeseriesrain of this Event.  # noqa: E501


        :return: The lizardtimeseriesrain of this Event.  # noqa: E501
        :rtype: list[LizardTimeseriesRain]
        """
        return self._lizardtimeseriesrain

    @lizardtimeseriesrain.setter
    def lizardtimeseriesrain(self, lizardtimeseriesrain):
        """Sets the lizardtimeseriesrain of this Event.


        :param lizardtimeseriesrain: The lizardtimeseriesrain of this Event.  # noqa: E501
        :type: list[LizardTimeseriesRain]
        """

        self._lizardtimeseriesrain = lizardtimeseriesrain

    @property
    def timeseriesrain(self):
        """Gets the timeseriesrain of this Event.  # noqa: E501


        :return: The timeseriesrain of this Event.  # noqa: E501
        :rtype: list[TimeseriesRainOverview]
        """
        return self._timeseriesrain

    @timeseriesrain.setter
    def timeseriesrain(self, timeseriesrain):
        """Sets the timeseriesrain of this Event.


        :param timeseriesrain: The timeseriesrain of this Event.  # noqa: E501
        :type: list[TimeseriesRainOverview]
        """

        self._timeseriesrain = timeseriesrain

    @property
    def breach(self):
        """Gets the breach of this Event.  # noqa: E501


        :return: The breach of this Event.  # noqa: E501
        :rtype: list[Breach]
        """
        return self._breach

    @breach.setter
    def breach(self, breach):
        """Sets the breach of this Event.


        :param breach: The breach of this Event.  # noqa: E501
        :type: list[Breach]
        """

        self._breach = breach

    @property
    def lizardrastersourcessinks(self):
        """Gets the lizardrastersourcessinks of this Event.  # noqa: E501


        :return: The lizardrastersourcessinks of this Event.  # noqa: E501
        :rtype: list[LizardRasterSourcesSinks]
        """
        return self._lizardrastersourcessinks

    @lizardrastersourcessinks.setter
    def lizardrastersourcessinks(self, lizardrastersourcessinks):
        """Sets the lizardrastersourcessinks of this Event.


        :param lizardrastersourcessinks: The lizardrastersourcessinks of this Event.  # noqa: E501
        :type: list[LizardRasterSourcesSinks]
        """

        self._lizardrastersourcessinks = lizardrastersourcessinks

    @property
    def lizardtimeseriessourcessinks(self):
        """Gets the lizardtimeseriessourcessinks of this Event.  # noqa: E501


        :return: The lizardtimeseriessourcessinks of this Event.  # noqa: E501
        :rtype: list[LizardTimeseriesSourcesSinks]
        """
        return self._lizardtimeseriessourcessinks

    @lizardtimeseriessourcessinks.setter
    def lizardtimeseriessourcessinks(self, lizardtimeseriessourcessinks):
        """Sets the lizardtimeseriessourcessinks of this Event.


        :param lizardtimeseriessourcessinks: The lizardtimeseriessourcessinks of this Event.  # noqa: E501
        :type: list[LizardTimeseriesSourcesSinks]
        """

        self._lizardtimeseriessourcessinks = lizardtimeseriessourcessinks

    @property
    def filerastersourcessinks(self):
        """Gets the filerastersourcessinks of this Event.  # noqa: E501


        :return: The filerastersourcessinks of this Event.  # noqa: E501
        :rtype: list[FileRasterSourcesSinks]
        """
        return self._filerastersourcessinks

    @filerastersourcessinks.setter
    def filerastersourcessinks(self, filerastersourcessinks):
        """Sets the filerastersourcessinks of this Event.


        :param filerastersourcessinks: The filerastersourcessinks of this Event.  # noqa: E501
        :type: list[FileRasterSourcesSinks]
        """

        self._filerastersourcessinks = filerastersourcessinks

    @property
    def filetimeseriessourcessinks(self):
        """Gets the filetimeseriessourcessinks of this Event.  # noqa: E501


        :return: The filetimeseriessourcessinks of this Event.  # noqa: E501
        :rtype: list[FileTimeseriesSourcesSinks]
        """
        return self._filetimeseriessourcessinks

    @filetimeseriessourcessinks.setter
    def filetimeseriessourcessinks(self, filetimeseriessourcessinks):
        """Sets the filetimeseriessourcessinks of this Event.


        :param filetimeseriessourcessinks: The filetimeseriessourcessinks of this Event.  # noqa: E501
        :type: list[FileTimeseriesSourcesSinks]
        """

        self._filetimeseriessourcessinks = filetimeseriessourcessinks

    @property
    def timeseriessourcessinks(self):
        """Gets the timeseriessourcessinks of this Event.  # noqa: E501


        :return: The timeseriessourcessinks of this Event.  # noqa: E501
        :rtype: list[TimeseriesSourcesSinksOverview]
        """
        return self._timeseriessourcessinks

    @timeseriessourcessinks.setter
    def timeseriessourcessinks(self, timeseriessourcessinks):
        """Sets the timeseriessourcessinks of this Event.


        :param timeseriessourcessinks: The timeseriessourcessinks of this Event.  # noqa: E501
        :type: list[TimeseriesSourcesSinksOverview]
        """

        self._timeseriessourcessinks = timeseriessourcessinks

    @property
    def leakage(self):
        """Gets the leakage of this Event.  # noqa: E501


        :return: The leakage of this Event.  # noqa: E501
        :rtype: list[TimeseriesLeakageOverview]
        """
        return self._leakage

    @leakage.setter
    def leakage(self, leakage):
        """Sets the leakage of this Event.


        :param leakage: The leakage of this Event.  # noqa: E501
        :type: list[TimeseriesLeakageOverview]
        """

        self._leakage = leakage

    @property
    def filetimeseriesleakage(self):
        """Gets the filetimeseriesleakage of this Event.  # noqa: E501


        :return: The filetimeseriesleakage of this Event.  # noqa: E501
        :rtype: list[FileTimeseriesLeakage]
        """
        return self._filetimeseriesleakage

    @filetimeseriesleakage.setter
    def filetimeseriesleakage(self, filetimeseriesleakage):
        """Sets the filetimeseriesleakage of this Event.


        :param filetimeseriesleakage: The filetimeseriesleakage of this Event.  # noqa: E501
        :type: list[FileTimeseriesLeakage]
        """

        self._filetimeseriesleakage = filetimeseriesleakage

    @property
    def filerasterleakage(self):
        """Gets the filerasterleakage of this Event.  # noqa: E501


        :return: The filerasterleakage of this Event.  # noqa: E501
        :rtype: list[FileRasterLeakage]
        """
        return self._filerasterleakage

    @filerasterleakage.setter
    def filerasterleakage(self, filerasterleakage):
        """Sets the filerasterleakage of this Event.


        :param filerasterleakage: The filerasterleakage of this Event.  # noqa: E501
        :type: list[FileRasterLeakage]
        """

        self._filerasterleakage = filerasterleakage

    @property
    def initial_twodwaterlevel(self):
        """Gets the initial_twodwaterlevel of this Event.  # noqa: E501


        :return: The initial_twodwaterlevel of this Event.  # noqa: E501
        :rtype: TwoDWaterLevel
        """
        return self._initial_twodwaterlevel

    @initial_twodwaterlevel.setter
    def initial_twodwaterlevel(self, initial_twodwaterlevel):
        """Sets the initial_twodwaterlevel of this Event.


        :param initial_twodwaterlevel: The initial_twodwaterlevel of this Event.  # noqa: E501
        :type: TwoDWaterLevel
        """

        self._initial_twodwaterlevel = initial_twodwaterlevel

    @property
    def initial_onedwaterlevelpredefined(self):
        """Gets the initial_onedwaterlevelpredefined of this Event.  # noqa: E501


        :return: The initial_onedwaterlevelpredefined of this Event.  # noqa: E501
        :rtype: OneDWaterLevelPredefined
        """
        return self._initial_onedwaterlevelpredefined

    @initial_onedwaterlevelpredefined.setter
    def initial_onedwaterlevelpredefined(self, initial_onedwaterlevelpredefined):
        """Sets the initial_onedwaterlevelpredefined of this Event.


        :param initial_onedwaterlevelpredefined: The initial_onedwaterlevelpredefined of this Event.  # noqa: E501
        :type: OneDWaterLevelPredefined
        """

        self._initial_onedwaterlevelpredefined = initial_onedwaterlevelpredefined

    @property
    def initial_groundwaterlevel(self):
        """Gets the initial_groundwaterlevel of this Event.  # noqa: E501


        :return: The initial_groundwaterlevel of this Event.  # noqa: E501
        :rtype: GroundWaterLevel
        """
        return self._initial_groundwaterlevel

    @initial_groundwaterlevel.setter
    def initial_groundwaterlevel(self, initial_groundwaterlevel):
        """Sets the initial_groundwaterlevel of this Event.


        :param initial_groundwaterlevel: The initial_groundwaterlevel of this Event.  # noqa: E501
        :type: GroundWaterLevel
        """

        self._initial_groundwaterlevel = initial_groundwaterlevel

    @property
    def initial_groundwaterraster(self):
        """Gets the initial_groundwaterraster of this Event.  # noqa: E501


        :return: The initial_groundwaterraster of this Event.  # noqa: E501
        :rtype: GroundWaterRaster
        """
        return self._initial_groundwaterraster

    @initial_groundwaterraster.setter
    def initial_groundwaterraster(self, initial_groundwaterraster):
        """Sets the initial_groundwaterraster of this Event.


        :param initial_groundwaterraster: The initial_groundwaterraster of this Event.  # noqa: E501
        :type: GroundWaterRaster
        """

        self._initial_groundwaterraster = initial_groundwaterraster

    @property
    def initial_onedwaterlevel(self):
        """Gets the initial_onedwaterlevel of this Event.  # noqa: E501


        :return: The initial_onedwaterlevel of this Event.  # noqa: E501
        :rtype: OneDWaterLevel
        """
        return self._initial_onedwaterlevel

    @initial_onedwaterlevel.setter
    def initial_onedwaterlevel(self, initial_onedwaterlevel):
        """Sets the initial_onedwaterlevel of this Event.


        :param initial_onedwaterlevel: The initial_onedwaterlevel of this Event.  # noqa: E501
        :type: OneDWaterLevel
        """

        self._initial_onedwaterlevel = initial_onedwaterlevel

    @property
    def initial_twodwaterraster(self):
        """Gets the initial_twodwaterraster of this Event.  # noqa: E501


        :return: The initial_twodwaterraster of this Event.  # noqa: E501
        :rtype: TwoDWaterRaster
        """
        return self._initial_twodwaterraster

    @initial_twodwaterraster.setter
    def initial_twodwaterraster(self, initial_twodwaterraster):
        """Sets the initial_twodwaterraster of this Event.


        :param initial_twodwaterraster: The initial_twodwaterraster of this Event.  # noqa: E501
        :type: TwoDWaterRaster
        """

        self._initial_twodwaterraster = initial_twodwaterraster

    @property
    def filerasterrain(self):
        """Gets the filerasterrain of this Event.  # noqa: E501


        :return: The filerasterrain of this Event.  # noqa: E501
        :rtype: list[FileRasterRain]
        """
        return self._filerasterrain

    @filerasterrain.setter
    def filerasterrain(self, filerasterrain):
        """Sets the filerasterrain of this Event.


        :param filerasterrain: The filerasterrain of this Event.  # noqa: E501
        :type: list[FileRasterRain]
        """

        self._filerasterrain = filerasterrain

    @property
    def filetimeseriesrain(self):
        """Gets the filetimeseriesrain of this Event.  # noqa: E501


        :return: The filetimeseriesrain of this Event.  # noqa: E501
        :rtype: list[FileTimeseriesRain]
        """
        return self._filetimeseriesrain

    @filetimeseriesrain.setter
    def filetimeseriesrain(self, filetimeseriesrain):
        """Sets the filetimeseriesrain of this Event.


        :param filetimeseriesrain: The filetimeseriesrain of this Event.  # noqa: E501
        :type: list[FileTimeseriesRain]
        """

        self._filetimeseriesrain = filetimeseriesrain

    @property
    def initial_savedstate(self):
        """Gets the initial_savedstate of this Event.  # noqa: E501


        :return: The initial_savedstate of this Event.  # noqa: E501
        :rtype: InitialSavedStateOverview
        """
        return self._initial_savedstate

    @initial_savedstate.setter
    def initial_savedstate(self, initial_savedstate):
        """Sets the initial_savedstate of this Event.


        :param initial_savedstate: The initial_savedstate of this Event.  # noqa: E501
        :type: InitialSavedStateOverview
        """

        self._initial_savedstate = initial_savedstate

    @property
    def savedstates(self):
        """Gets the savedstates of this Event.  # noqa: E501


        :return: The savedstates of this Event.  # noqa: E501
        :rtype: list[SavedStateOverview]
        """
        return self._savedstates

    @savedstates.setter
    def savedstates(self, savedstates):
        """Sets the savedstates of this Event.


        :param savedstates: The savedstates of this Event.  # noqa: E501
        :type: list[SavedStateOverview]
        """

        self._savedstates = savedstates

    @property
    def laterals(self):
        """Gets the laterals of this Event.  # noqa: E501


        :return: The laterals of this Event.  # noqa: E501
        :rtype: list[Lateral]
        """
        return self._laterals

    @laterals.setter
    def laterals(self, laterals):
        """Sets the laterals of this Event.


        :param laterals: The laterals of this Event.  # noqa: E501
        :type: list[Lateral]
        """

        self._laterals = laterals

    @property
    def filelaterals(self):
        """Gets the filelaterals of this Event.  # noqa: E501


        :return: The filelaterals of this Event.  # noqa: E501
        :rtype: list[FileLateral]
        """
        return self._filelaterals

    @filelaterals.setter
    def filelaterals(self, filelaterals):
        """Sets the filelaterals of this Event.


        :param filelaterals: The filelaterals of this Event.  # noqa: E501
        :type: list[FileLateral]
        """

        self._filelaterals = filelaterals

    @property
    def fileboundaryconditions(self):
        """Gets the fileboundaryconditions of this Event.  # noqa: E501


        :return: The fileboundaryconditions of this Event.  # noqa: E501
        :rtype: FileBoundaryCondition
        """
        return self._fileboundaryconditions

    @fileboundaryconditions.setter
    def fileboundaryconditions(self, fileboundaryconditions):
        """Sets the fileboundaryconditions of this Event.


        :param fileboundaryconditions: The fileboundaryconditions of this Event.  # noqa: E501
        :type: FileBoundaryCondition
        """

        self._fileboundaryconditions = fileboundaryconditions

    @property
    def tablestructurecontrols(self):
        """Gets the tablestructurecontrols of this Event.  # noqa: E501


        :return: The tablestructurecontrols of this Event.  # noqa: E501
        :rtype: list[TableStructureControl]
        """
        return self._tablestructurecontrols

    @tablestructurecontrols.setter
    def tablestructurecontrols(self, tablestructurecontrols):
        """Sets the tablestructurecontrols of this Event.


        :param tablestructurecontrols: The tablestructurecontrols of this Event.  # noqa: E501
        :type: list[TableStructureControl]
        """

        self._tablestructurecontrols = tablestructurecontrols

    @property
    def memorystructurecontrols(self):
        """Gets the memorystructurecontrols of this Event.  # noqa: E501


        :return: The memorystructurecontrols of this Event.  # noqa: E501
        :rtype: list[MemoryStructureControl]
        """
        return self._memorystructurecontrols

    @memorystructurecontrols.setter
    def memorystructurecontrols(self, memorystructurecontrols):
        """Sets the memorystructurecontrols of this Event.


        :param memorystructurecontrols: The memorystructurecontrols of this Event.  # noqa: E501
        :type: list[MemoryStructureControl]
        """

        self._memorystructurecontrols = memorystructurecontrols

    @property
    def timedstructurecontrols(self):
        """Gets the timedstructurecontrols of this Event.  # noqa: E501


        :return: The timedstructurecontrols of this Event.  # noqa: E501
        :rtype: list[TimedStructureControl]
        """
        return self._timedstructurecontrols

    @timedstructurecontrols.setter
    def timedstructurecontrols(self, timedstructurecontrols):
        """Sets the timedstructurecontrols of this Event.


        :param timedstructurecontrols: The timedstructurecontrols of this Event.  # noqa: E501
        :type: list[TimedStructureControl]
        """

        self._timedstructurecontrols = timedstructurecontrols

    @property
    def rasteredits(self):
        """Gets the rasteredits of this Event.  # noqa: E501


        :return: The rasteredits of this Event.  # noqa: E501
        :rtype: list[RasterEdit]
        """
        return self._rasteredits

    @rasteredits.setter
    def rasteredits(self, rasteredits):
        """Sets the rasteredits of this Event.


        :param rasteredits: The rasteredits of this Event.  # noqa: E501
        :type: list[RasterEdit]
        """

        self._rasteredits = rasteredits

    @property
    def localrain(self):
        """Gets the localrain of this Event.  # noqa: E501


        :return: The localrain of this Event.  # noqa: E501
        :rtype: list[LocalRain]
        """
        return self._localrain

    @localrain.setter
    def localrain(self, localrain):
        """Sets the localrain of this Event.


        :param localrain: The localrain of this Event.  # noqa: E501
        :type: list[LocalRain]
        """

        self._localrain = localrain

    @property
    def wind(self):
        """Gets the wind of this Event.  # noqa: E501


        :return: The wind of this Event.  # noqa: E501
        :rtype: list[Wind]
        """
        return self._wind

    @wind.setter
    def wind(self, wind):
        """Sets the wind of this Event.


        :param wind: The wind of this Event.  # noqa: E501
        :type: list[Wind]
        """

        self._wind = wind

    @property
    def initial_winddragcoefficient(self):
        """Gets the initial_winddragcoefficient of this Event.  # noqa: E501


        :return: The initial_winddragcoefficient of this Event.  # noqa: E501
        :rtype: WindDragCoefficient
        """
        return self._initial_winddragcoefficient

    @initial_winddragcoefficient.setter
    def initial_winddragcoefficient(self, initial_winddragcoefficient):
        """Sets the initial_winddragcoefficient of this Event.


        :param initial_winddragcoefficient: The initial_winddragcoefficient of this Event.  # noqa: E501
        :type: WindDragCoefficient
        """

        self._initial_winddragcoefficient = initial_winddragcoefficient

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Event):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class NumericalSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'simulation_id': 'int',
        'pump_implicit_ratio': 'float',
        'cfl_strictness_factor_1d': 'float',
        'cfl_strictness_factor_2d': 'float',
        'convergence_cg': 'float',
        'flow_direction_threshold': 'float',
        'friction_shallow_water_depth_correction': 'int',
        'general_numerical_threshold': 'float',
        'time_integration_method': 'int',
        'limiter_waterlevel_gradient_1d': 'int',
        'limiter_waterlevel_gradient_2d': 'int',
        'limiter_slope_crossectional_area_2d': 'int',
        'limiter_slope_friction_2d': 'int',
        'max_non_linear_newton_iterations': 'int',
        'max_degree_gauss_seidel': 'int',
        'min_friction_velocity': 'float',
        'min_surface_area': 'float',
        'use_preconditioner_cg': 'int',
        'preissmann_slot': 'float',
        'limiter_slope_thin_water_layer': 'float',
        'use_of_cg': 'int',
        'use_nested_newton': 'bool',
        'flooding_threshold': 'float'
    }

    attribute_map = {
        'id': 'id',
        'simulation_id': 'simulation_id',
        'pump_implicit_ratio': 'pump_implicit_ratio',
        'cfl_strictness_factor_1d': 'cfl_strictness_factor_1d',
        'cfl_strictness_factor_2d': 'cfl_strictness_factor_2d',
        'convergence_cg': 'convergence_cg',
        'flow_direction_threshold': 'flow_direction_threshold',
        'friction_shallow_water_depth_correction': 'friction_shallow_water_depth_correction',
        'general_numerical_threshold': 'general_numerical_threshold',
        'time_integration_method': 'time_integration_method',
        'limiter_waterlevel_gradient_1d': 'limiter_waterlevel_gradient_1d',
        'limiter_waterlevel_gradient_2d': 'limiter_waterlevel_gradient_2d',
        'limiter_slope_crossectional_area_2d': 'limiter_slope_crossectional_area_2d',
        'limiter_slope_friction_2d': 'limiter_slope_friction_2d',
        'max_non_linear_newton_iterations': 'max_non_linear_newton_iterations',
        'max_degree_gauss_seidel': 'max_degree_gauss_seidel',
        'min_friction_velocity': 'min_friction_velocity',
        'min_surface_area': 'min_surface_area',
        'use_preconditioner_cg': 'use_preconditioner_cg',
        'preissmann_slot': 'preissmann_slot',
        'limiter_slope_thin_water_layer': 'limiter_slope_thin_water_layer',
        'use_of_cg': 'use_of_cg',
        'use_nested_newton': 'use_nested_newton',
        'flooding_threshold': 'flooding_threshold'
    }

    def __init__(self, id=None, simulation_id=None, pump_implicit_ratio=None, cfl_strictness_factor_1d=None, cfl_strictness_factor_2d=None, convergence_cg=None, flow_direction_threshold=None, friction_shallow_water_depth_correction=None, general_numerical_threshold=None, time_integration_method=None, limiter_waterlevel_gradient_1d=None, limiter_waterlevel_gradient_2d=None, limiter_slope_crossectional_area_2d=None, limiter_slope_friction_2d=None, max_non_linear_newton_iterations=None, max_degree_gauss_seidel=None, min_friction_velocity=None, min_surface_area=None, use_preconditioner_cg=None, preissmann_slot=None, limiter_slope_thin_water_layer=None, use_of_cg=None, use_nested_newton=None, flooding_threshold=None, local_vars_configuration=None):  # noqa: E501
        """NumericalSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._simulation_id = None
        self._pump_implicit_ratio = None
        self._cfl_strictness_factor_1d = None
        self._cfl_strictness_factor_2d = None
        self._convergence_cg = None
        self._flow_direction_threshold = None
        self._friction_shallow_water_depth_correction = None
        self._general_numerical_threshold = None
        self._time_integration_method = None
        self._limiter_waterlevel_gradient_1d = None
        self._limiter_waterlevel_gradient_2d = None
        self._limiter_slope_crossectional_area_2d = None
        self._limiter_slope_friction_2d = None
        self._max_non_linear_newton_iterations = None
        self._max_degree_gauss_seidel = None
        self._min_friction_velocity = None
        self._min_surface_area = None
        self._use_preconditioner_cg = None
        self._preissmann_slot = None
        self._limiter_slope_thin_water_layer = None
        self._use_of_cg = None
        self._use_nested_newton = None
        self._flooding_threshold = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if simulation_id is not None:
            self.simulation_id = simulation_id
        self.pump_implicit_ratio = pump_implicit_ratio
        self.cfl_strictness_factor_1d = cfl_strictness_factor_1d
        self.cfl_strictness_factor_2d = cfl_strictness_factor_2d
        self.convergence_cg = convergence_cg
        self.flow_direction_threshold = flow_direction_threshold
        self.friction_shallow_water_depth_correction = friction_shallow_water_depth_correction
        self.general_numerical_threshold = general_numerical_threshold
        if time_integration_method is not None:
            self.time_integration_method = time_integration_method
        self.limiter_waterlevel_gradient_1d = limiter_waterlevel_gradient_1d
        self.limiter_waterlevel_gradient_2d = limiter_waterlevel_gradient_2d
        self.limiter_slope_crossectional_area_2d = limiter_slope_crossectional_area_2d
        self.limiter_slope_friction_2d = limiter_slope_friction_2d
        self.max_non_linear_newton_iterations = max_non_linear_newton_iterations
        self.max_degree_gauss_seidel = max_degree_gauss_seidel
        self.min_friction_velocity = min_friction_velocity
        self.min_surface_area = min_surface_area
        self.use_preconditioner_cg = use_preconditioner_cg
        self.preissmann_slot = preissmann_slot
        self.limiter_slope_thin_water_layer = limiter_slope_thin_water_layer
        self.use_of_cg = use_of_cg
        self.use_nested_newton = use_nested_newton
        self.flooding_threshold = flooding_threshold

    @property
    def id(self):
        """Gets the id of this NumericalSettings.  # noqa: E501


        :return: The id of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NumericalSettings.


        :param id: The id of this NumericalSettings.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def simulation_id(self):
        """Gets the simulation_id of this NumericalSettings.  # noqa: E501


        :return: The simulation_id of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._simulation_id

    @simulation_id.setter
    def simulation_id(self, simulation_id):
        """Sets the simulation_id of this NumericalSettings.


        :param simulation_id: The simulation_id of this NumericalSettings.  # noqa: E501
        :type: int
        """

        self._simulation_id = simulation_id

    @property
    def pump_implicit_ratio(self):
        """Gets the pump_implicit_ratio of this NumericalSettings.  # noqa: E501


        :return: The pump_implicit_ratio of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._pump_implicit_ratio

    @pump_implicit_ratio.setter
    def pump_implicit_ratio(self, pump_implicit_ratio):
        """Sets the pump_implicit_ratio of this NumericalSettings.


        :param pump_implicit_ratio: The pump_implicit_ratio of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and pump_implicit_ratio is None:  # noqa: E501
            raise ValueError("Invalid value for `pump_implicit_ratio`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                pump_implicit_ratio is not None and pump_implicit_ratio > 1):  # noqa: E501
            raise ValueError("Invalid value for `pump_implicit_ratio`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                pump_implicit_ratio is not None and pump_implicit_ratio < 0):  # noqa: E501
            raise ValueError("Invalid value for `pump_implicit_ratio`, must be a value greater than or equal to `0`")  # noqa: E501

        self._pump_implicit_ratio = pump_implicit_ratio

    @property
    def cfl_strictness_factor_1d(self):
        """Gets the cfl_strictness_factor_1d of this NumericalSettings.  # noqa: E501

        Strictness of CFL (Courant–Friedrichs–Lewy) condition for 1D.  # noqa: E501

        :return: The cfl_strictness_factor_1d of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._cfl_strictness_factor_1d

    @cfl_strictness_factor_1d.setter
    def cfl_strictness_factor_1d(self, cfl_strictness_factor_1d):
        """Sets the cfl_strictness_factor_1d of this NumericalSettings.

        Strictness of CFL (Courant–Friedrichs–Lewy) condition for 1D.  # noqa: E501

        :param cfl_strictness_factor_1d: The cfl_strictness_factor_1d of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and cfl_strictness_factor_1d is None:  # noqa: E501
            raise ValueError("Invalid value for `cfl_strictness_factor_1d`, must not be `None`")  # noqa: E501

        self._cfl_strictness_factor_1d = cfl_strictness_factor_1d

    @property
    def cfl_strictness_factor_2d(self):
        """Gets the cfl_strictness_factor_2d of this NumericalSettings.  # noqa: E501

        Strictness of CFL (Courant–Friedrichs–Lewy) condition for 2D.  # noqa: E501

        :return: The cfl_strictness_factor_2d of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._cfl_strictness_factor_2d

    @cfl_strictness_factor_2d.setter
    def cfl_strictness_factor_2d(self, cfl_strictness_factor_2d):
        """Sets the cfl_strictness_factor_2d of this NumericalSettings.

        Strictness of CFL (Courant–Friedrichs–Lewy) condition for 2D.  # noqa: E501

        :param cfl_strictness_factor_2d: The cfl_strictness_factor_2d of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and cfl_strictness_factor_2d is None:  # noqa: E501
            raise ValueError("Invalid value for `cfl_strictness_factor_2d`, must not be `None`")  # noqa: E501

        self._cfl_strictness_factor_2d = cfl_strictness_factor_2d

    @property
    def convergence_cg(self):
        """Gets the convergence_cg of this NumericalSettings.  # noqa: E501

        Convergence criterion of cg-method, suitable default is 1.0e-9, due to numerical precision.  # noqa: E501

        :return: The convergence_cg of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._convergence_cg

    @convergence_cg.setter
    def convergence_cg(self, convergence_cg):
        """Sets the convergence_cg of this NumericalSettings.

        Convergence criterion of cg-method, suitable default is 1.0e-9, due to numerical precision.  # noqa: E501

        :param convergence_cg: The convergence_cg of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and convergence_cg is None:  # noqa: E501
            raise ValueError("Invalid value for `convergence_cg`, must not be `None`")  # noqa: E501

        self._convergence_cg = convergence_cg

    @property
    def flow_direction_threshold(self):
        """Gets the flow_direction_threshold of this NumericalSettings.  # noqa: E501

        Threshold value for upwind scheme based on flow velocity, suitable default is 1e-06.  # noqa: E501

        :return: The flow_direction_threshold of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._flow_direction_threshold

    @flow_direction_threshold.setter
    def flow_direction_threshold(self, flow_direction_threshold):
        """Sets the flow_direction_threshold of this NumericalSettings.

        Threshold value for upwind scheme based on flow velocity, suitable default is 1e-06.  # noqa: E501

        :param flow_direction_threshold: The flow_direction_threshold of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and flow_direction_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `flow_direction_threshold`, must not be `None`")  # noqa: E501

        self._flow_direction_threshold = flow_direction_threshold

    @property
    def friction_shallow_water_depth_correction(self):
        """Gets the friction_shallow_water_depth_correction of this NumericalSettings.  # noqa: E501

        In case the friction assumptions based on the dominant friction balance gives a structurally underestimation of the friction, you can switch this setting on.  Options:  0 = off 1 = max between avg and divided channel based friction 2 = always linearized 3 = linearizes the depth based on a weighed averaged   If options 3 is used the maximum depth of a thin layer needs to be defined. Do not use in combination with interflow. Suitable default is 0 (OFF).  # noqa: E501

        :return: The friction_shallow_water_depth_correction of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._friction_shallow_water_depth_correction

    @friction_shallow_water_depth_correction.setter
    def friction_shallow_water_depth_correction(self, friction_shallow_water_depth_correction):
        """Sets the friction_shallow_water_depth_correction of this NumericalSettings.

        In case the friction assumptions based on the dominant friction balance gives a structurally underestimation of the friction, you can switch this setting on.  Options:  0 = off 1 = max between avg and divided channel based friction 2 = always linearized 3 = linearizes the depth based on a weighed averaged   If options 3 is used the maximum depth of a thin layer needs to be defined. Do not use in combination with interflow. Suitable default is 0 (OFF).  # noqa: E501

        :param friction_shallow_water_depth_correction: The friction_shallow_water_depth_correction of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and friction_shallow_water_depth_correction is None:  # noqa: E501
            raise ValueError("Invalid value for `friction_shallow_water_depth_correction`, must not be `None`")  # noqa: E501

        self._friction_shallow_water_depth_correction = friction_shallow_water_depth_correction

    @property
    def general_numerical_threshold(self):
        """Gets the general_numerical_threshold of this NumericalSettings.  # noqa: E501

        Suitable default is 1.0e-8  # noqa: E501

        :return: The general_numerical_threshold of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._general_numerical_threshold

    @general_numerical_threshold.setter
    def general_numerical_threshold(self, general_numerical_threshold):
        """Sets the general_numerical_threshold of this NumericalSettings.

        Suitable default is 1.0e-8  # noqa: E501

        :param general_numerical_threshold: The general_numerical_threshold of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and general_numerical_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `general_numerical_threshold`, must not be `None`")  # noqa: E501

        self._general_numerical_threshold = general_numerical_threshold

    @property
    def time_integration_method(self):
        """Gets the time_integration_method of this NumericalSettings.  # noqa: E501

        There are various methods to discretize the equations. At the moment only the first-order, semi-implicit method is supported and tested. Options:  0 = euler implicit   # noqa: E501

        :return: The time_integration_method of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._time_integration_method

    @time_integration_method.setter
    def time_integration_method(self, time_integration_method):
        """Sets the time_integration_method of this NumericalSettings.

        There are various methods to discretize the equations. At the moment only the first-order, semi-implicit method is supported and tested. Options:  0 = euler implicit   # noqa: E501

        :param time_integration_method: The time_integration_method of this NumericalSettings.  # noqa: E501
        :type: int
        """

        self._time_integration_method = time_integration_method

    @property
    def limiter_waterlevel_gradient_1d(self):
        """Gets the limiter_waterlevel_gradient_1d of this NumericalSettings.  # noqa: E501

        The limiter on the water level gradient allows the model to deal with unrealistically steep gradients. Suitable default is 1.  # noqa: E501

        :return: The limiter_waterlevel_gradient_1d of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._limiter_waterlevel_gradient_1d

    @limiter_waterlevel_gradient_1d.setter
    def limiter_waterlevel_gradient_1d(self, limiter_waterlevel_gradient_1d):
        """Sets the limiter_waterlevel_gradient_1d of this NumericalSettings.

        The limiter on the water level gradient allows the model to deal with unrealistically steep gradients. Suitable default is 1.  # noqa: E501

        :param limiter_waterlevel_gradient_1d: The limiter_waterlevel_gradient_1d of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and limiter_waterlevel_gradient_1d is None:  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_1d`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limiter_waterlevel_gradient_1d is not None and limiter_waterlevel_gradient_1d > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_1d`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limiter_waterlevel_gradient_1d is not None and limiter_waterlevel_gradient_1d < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_1d`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._limiter_waterlevel_gradient_1d = limiter_waterlevel_gradient_1d

    @property
    def limiter_waterlevel_gradient_2d(self):
        """Gets the limiter_waterlevel_gradient_2d of this NumericalSettings.  # noqa: E501

        The limiter on the water level gradient allows the model to deal with unrealistically steep gradients. Suitable default is 1.  # noqa: E501

        :return: The limiter_waterlevel_gradient_2d of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._limiter_waterlevel_gradient_2d

    @limiter_waterlevel_gradient_2d.setter
    def limiter_waterlevel_gradient_2d(self, limiter_waterlevel_gradient_2d):
        """Sets the limiter_waterlevel_gradient_2d of this NumericalSettings.

        The limiter on the water level gradient allows the model to deal with unrealistically steep gradients. Suitable default is 1.  # noqa: E501

        :param limiter_waterlevel_gradient_2d: The limiter_waterlevel_gradient_2d of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and limiter_waterlevel_gradient_2d is None:  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_2d`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limiter_waterlevel_gradient_2d is not None and limiter_waterlevel_gradient_2d > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_2d`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limiter_waterlevel_gradient_2d is not None and limiter_waterlevel_gradient_2d < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `limiter_waterlevel_gradient_2d`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._limiter_waterlevel_gradient_2d = limiter_waterlevel_gradient_2d

    @property
    def limiter_slope_crossectional_area_2d(self):
        """Gets the limiter_slope_crossectional_area_2d of this NumericalSettings.  # noqa: E501

        This limiter starts working in case the depth based on the downstream water level is zero and may be useful in sloping areas. Options:  0 = off 1 = higher order scheme (might be sensitive to instabilities) 2 = cross-sections treated as upwind method volume/surface area 3 = combination traditional method thin layer approach  If options 3 is used the maximum depth of a thin layer needs to be defined. Do not use in combination with interflow  # noqa: E501

        :return: The limiter_slope_crossectional_area_2d of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._limiter_slope_crossectional_area_2d

    @limiter_slope_crossectional_area_2d.setter
    def limiter_slope_crossectional_area_2d(self, limiter_slope_crossectional_area_2d):
        """Sets the limiter_slope_crossectional_area_2d of this NumericalSettings.

        This limiter starts working in case the depth based on the downstream water level is zero and may be useful in sloping areas. Options:  0 = off 1 = higher order scheme (might be sensitive to instabilities) 2 = cross-sections treated as upwind method volume/surface area 3 = combination traditional method thin layer approach  If options 3 is used the maximum depth of a thin layer needs to be defined. Do not use in combination with interflow  # noqa: E501

        :param limiter_slope_crossectional_area_2d: The limiter_slope_crossectional_area_2d of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and limiter_slope_crossectional_area_2d is None:  # noqa: E501
            raise ValueError("Invalid value for `limiter_slope_crossectional_area_2d`, must not be `None`")  # noqa: E501

        self._limiter_slope_crossectional_area_2d = limiter_slope_crossectional_area_2d

    @property
    def limiter_slope_friction_2d(self):
        """Gets the limiter_slope_friction_2d of this NumericalSettings.  # noqa: E501

        This limiter starts working in case the depth based on the downstream water level is zero and may be useful in sloping areas. This limiter is mandatory if the limiter_slope_crossectional_area_2d settings is greater than 0. Do not use in combination with interflow. Suitable default is 0 (OFF)  Options:  0 = off 1 = standard   # noqa: E501

        :return: The limiter_slope_friction_2d of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._limiter_slope_friction_2d

    @limiter_slope_friction_2d.setter
    def limiter_slope_friction_2d(self, limiter_slope_friction_2d):
        """Sets the limiter_slope_friction_2d of this NumericalSettings.

        This limiter starts working in case the depth based on the downstream water level is zero and may be useful in sloping areas. This limiter is mandatory if the limiter_slope_crossectional_area_2d settings is greater than 0. Do not use in combination with interflow. Suitable default is 0 (OFF)  Options:  0 = off 1 = standard   # noqa: E501

        :param limiter_slope_friction_2d: The limiter_slope_friction_2d of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and limiter_slope_friction_2d is None:  # noqa: E501
            raise ValueError("Invalid value for `limiter_slope_friction_2d`, must not be `None`")  # noqa: E501

        self._limiter_slope_friction_2d = limiter_slope_friction_2d

    @property
    def max_non_linear_newton_iterations(self):
        """Gets the max_non_linear_newton_iterations of this NumericalSettings.  # noqa: E501

        Maximum number of non-linear newton iterations in single time step. Suitable default is 20.  # noqa: E501

        :return: The max_non_linear_newton_iterations of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._max_non_linear_newton_iterations

    @max_non_linear_newton_iterations.setter
    def max_non_linear_newton_iterations(self, max_non_linear_newton_iterations):
        """Sets the max_non_linear_newton_iterations of this NumericalSettings.

        Maximum number of non-linear newton iterations in single time step. Suitable default is 20.  # noqa: E501

        :param max_non_linear_newton_iterations: The max_non_linear_newton_iterations of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_non_linear_newton_iterations is None:  # noqa: E501
            raise ValueError("Invalid value for `max_non_linear_newton_iterations`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_non_linear_newton_iterations is not None and max_non_linear_newton_iterations > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `max_non_linear_newton_iterations`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_non_linear_newton_iterations is not None and max_non_linear_newton_iterations < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `max_non_linear_newton_iterations`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._max_non_linear_newton_iterations = max_non_linear_newton_iterations

    @property
    def max_degree_gauss_seidel(self):
        """Gets the max_degree_gauss_seidel of this NumericalSettings.  # noqa: E501

        Values below are advised for different model types:  700 for 1D flow  7 for 1D and 2D flow  5 for surface 2D flow only  7 for surface and groundwater flow  70 for 1D, 2D surface and groundwater flow or higher.  Play around with this value, can speed up your model significantly, especially in case of ground water flow. Suitable default is 0.  # noqa: E501

        :return: The max_degree_gauss_seidel of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._max_degree_gauss_seidel

    @max_degree_gauss_seidel.setter
    def max_degree_gauss_seidel(self, max_degree_gauss_seidel):
        """Sets the max_degree_gauss_seidel of this NumericalSettings.

        Values below are advised for different model types:  700 for 1D flow  7 for 1D and 2D flow  5 for surface 2D flow only  7 for surface and groundwater flow  70 for 1D, 2D surface and groundwater flow or higher.  Play around with this value, can speed up your model significantly, especially in case of ground water flow. Suitable default is 0.  # noqa: E501

        :param max_degree_gauss_seidel: The max_degree_gauss_seidel of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_degree_gauss_seidel is None:  # noqa: E501
            raise ValueError("Invalid value for `max_degree_gauss_seidel`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_degree_gauss_seidel is not None and max_degree_gauss_seidel > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `max_degree_gauss_seidel`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_degree_gauss_seidel is not None and max_degree_gauss_seidel < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_degree_gauss_seidel`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_degree_gauss_seidel = max_degree_gauss_seidel

    @property
    def min_friction_velocity(self):
        """Gets the min_friction_velocity of this NumericalSettings.  # noqa: E501

        To guarantee some initial friction only in flooded areas and for large time steps, it is wise to assume a minimum velocityfor computing the friction. Suitable default is 0.01.  # noqa: E501

        :return: The min_friction_velocity of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._min_friction_velocity

    @min_friction_velocity.setter
    def min_friction_velocity(self, min_friction_velocity):
        """Sets the min_friction_velocity of this NumericalSettings.

        To guarantee some initial friction only in flooded areas and for large time steps, it is wise to assume a minimum velocityfor computing the friction. Suitable default is 0.01.  # noqa: E501

        :param min_friction_velocity: The min_friction_velocity of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and min_friction_velocity is None:  # noqa: E501
            raise ValueError("Invalid value for `min_friction_velocity`, must not be `None`")  # noqa: E501

        self._min_friction_velocity = min_friction_velocity

    @property
    def min_surface_area(self):
        """Gets the min_surface_area of this NumericalSettings.  # noqa: E501

        Suitable default is 1.0e-8.  # noqa: E501

        :return: The min_surface_area of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._min_surface_area

    @min_surface_area.setter
    def min_surface_area(self, min_surface_area):
        """Sets the min_surface_area of this NumericalSettings.

        Suitable default is 1.0e-8.  # noqa: E501

        :param min_surface_area: The min_surface_area of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and min_surface_area is None:  # noqa: E501
            raise ValueError("Invalid value for `min_surface_area`, must not be `None`")  # noqa: E501

        self._min_surface_area = min_surface_area

    @property
    def use_preconditioner_cg(self):
        """Gets the use_preconditioner_cg of this NumericalSettings.  # noqa: E501

        Use pre-conditioner for matrix solver. Increases simulation speed in most cases.  Options:  0 = off 1 = standard . Suitable default is 1 (STANDARD).  # noqa: E501

        :return: The use_preconditioner_cg of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._use_preconditioner_cg

    @use_preconditioner_cg.setter
    def use_preconditioner_cg(self, use_preconditioner_cg):
        """Sets the use_preconditioner_cg of this NumericalSettings.

        Use pre-conditioner for matrix solver. Increases simulation speed in most cases.  Options:  0 = off 1 = standard . Suitable default is 1 (STANDARD).  # noqa: E501

        :param use_preconditioner_cg: The use_preconditioner_cg of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and use_preconditioner_cg is None:  # noqa: E501
            raise ValueError("Invalid value for `use_preconditioner_cg`, must not be `None`")  # noqa: E501

        self._use_preconditioner_cg = use_preconditioner_cg

    @property
    def preissmann_slot(self):
        """Gets the preissmann_slot of this NumericalSettings.  # noqa: E501

        A conceptual vertical narrow slot providing a conceptual free surface condition for the flow when the water level is above the top of a closed conduit. Often used to guarantee stability. Not necessary in 3Di even for pressurized pipe flow. Note: Works only for circular profiles. Suitable default is 0.0. Unit: m2.  # noqa: E501

        :return: The preissmann_slot of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._preissmann_slot

    @preissmann_slot.setter
    def preissmann_slot(self, preissmann_slot):
        """Sets the preissmann_slot of this NumericalSettings.

        A conceptual vertical narrow slot providing a conceptual free surface condition for the flow when the water level is above the top of a closed conduit. Often used to guarantee stability. Not necessary in 3Di even for pressurized pipe flow. Note: Works only for circular profiles. Suitable default is 0.0. Unit: m2.  # noqa: E501

        :param preissmann_slot: The preissmann_slot of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and preissmann_slot is None:  # noqa: E501
            raise ValueError("Invalid value for `preissmann_slot`, must not be `None`")  # noqa: E501

        self._preissmann_slot = preissmann_slot

    @property
    def limiter_slope_thin_water_layer(self):
        """Gets the limiter_slope_thin_water_layer of this NumericalSettings.  # noqa: E501

        Mandatory when using friction_shallow_water_depth_correction option 3 or limiter_slope_crossectional_area_2d option 3. Unit: m  # noqa: E501

        :return: The limiter_slope_thin_water_layer of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._limiter_slope_thin_water_layer

    @limiter_slope_thin_water_layer.setter
    def limiter_slope_thin_water_layer(self, limiter_slope_thin_water_layer):
        """Sets the limiter_slope_thin_water_layer of this NumericalSettings.

        Mandatory when using friction_shallow_water_depth_correction option 3 or limiter_slope_crossectional_area_2d option 3. Unit: m  # noqa: E501

        :param limiter_slope_thin_water_layer: The limiter_slope_thin_water_layer of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and limiter_slope_thin_water_layer is None:  # noqa: E501
            raise ValueError("Invalid value for `limiter_slope_thin_water_layer`, must not be `None`")  # noqa: E501

        self._limiter_slope_thin_water_layer = limiter_slope_thin_water_layer

    @property
    def use_of_cg(self):
        """Gets the use_of_cg of this NumericalSettings.  # noqa: E501

        Number of conjugate gradient method iterations, before switching to another method. Suitable default is 20.  # noqa: E501

        :return: The use_of_cg of this NumericalSettings.  # noqa: E501
        :rtype: int
        """
        return self._use_of_cg

    @use_of_cg.setter
    def use_of_cg(self, use_of_cg):
        """Sets the use_of_cg of this NumericalSettings.

        Number of conjugate gradient method iterations, before switching to another method. Suitable default is 20.  # noqa: E501

        :param use_of_cg: The use_of_cg of this NumericalSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and use_of_cg is None:  # noqa: E501
            raise ValueError("Invalid value for `use_of_cg`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                use_of_cg is not None and use_of_cg > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `use_of_cg`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                use_of_cg is not None and use_of_cg < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `use_of_cg`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._use_of_cg = use_of_cg

    @property
    def use_nested_newton(self):
        """Gets the use_nested_newton of this NumericalSettings.  # noqa: E501

        Set to 'True' for 1D calculations with closed profiles to handle non-linearity in volume-water level relation. When set to 'False' it will be used if calculations become non-linear. For sewerage systems it is advised to set this setting to 'True'. Otherwise a suitable default is 'False'  # noqa: E501

        :return: The use_nested_newton of this NumericalSettings.  # noqa: E501
        :rtype: bool
        """
        return self._use_nested_newton

    @use_nested_newton.setter
    def use_nested_newton(self, use_nested_newton):
        """Sets the use_nested_newton of this NumericalSettings.

        Set to 'True' for 1D calculations with closed profiles to handle non-linearity in volume-water level relation. When set to 'False' it will be used if calculations become non-linear. For sewerage systems it is advised to set this setting to 'True'. Otherwise a suitable default is 'False'  # noqa: E501

        :param use_nested_newton: The use_nested_newton of this NumericalSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and use_nested_newton is None:  # noqa: E501
            raise ValueError("Invalid value for `use_nested_newton`, must not be `None`")  # noqa: E501

        self._use_nested_newton = use_nested_newton

    @property
    def flooding_threshold(self):
        """Gets the flooding_threshold of this NumericalSettings.  # noqa: E501

        Water depth threshold for flow between 2D cells. Depth relative to lowest bathymetry pixel at the edge between two 2D cells. Suitable default is 0.000001.  # noqa: E501

        :return: The flooding_threshold of this NumericalSettings.  # noqa: E501
        :rtype: float
        """
        return self._flooding_threshold

    @flooding_threshold.setter
    def flooding_threshold(self, flooding_threshold):
        """Sets the flooding_threshold of this NumericalSettings.

        Water depth threshold for flow between 2D cells. Depth relative to lowest bathymetry pixel at the edge between two 2D cells. Suitable default is 0.000001.  # noqa: E501

        :param flooding_threshold: The flooding_threshold of this NumericalSettings.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and flooding_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `flooding_threshold`, must not be `None`")  # noqa: E501

        self._flooding_threshold = flooding_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NumericalSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NumericalSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    3Di API

    3Di simulation API (latest version: 3.0)   Framework release: 1.0.16   3Di core release: 2.0.11  deployed on:  07:33AM (UTC) on September 04, 2020  # noqa: E501

    The version of the OpenAPI document: 3.0
    Contact: info@nelen-schuurmans.nl
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class DamagePostProcessing(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'basic_post_processing': 'int',
        'cost_type': 'str',
        'flood_month': 'str',
        'inundation_period': 'float',
        'repair_time_infrastructure': 'int',
        'repair_time_buildings': 'int'
    }

    attribute_map = {
        'basic_post_processing': 'basic_post_processing',
        'cost_type': 'cost_type',
        'flood_month': 'flood_month',
        'inundation_period': 'inundation_period',
        'repair_time_infrastructure': 'repair_time_infrastructure',
        'repair_time_buildings': 'repair_time_buildings'
    }

    def __init__(self, basic_post_processing=None, cost_type=None, flood_month=None, inundation_period=None, repair_time_infrastructure=None, repair_time_buildings=None, local_vars_configuration=None):  # noqa: E501
        """DamagePostProcessing - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._basic_post_processing = None
        self._cost_type = None
        self._flood_month = None
        self._inundation_period = None
        self._repair_time_infrastructure = None
        self._repair_time_buildings = None
        self.discriminator = None

        if basic_post_processing is not None:
            self.basic_post_processing = basic_post_processing
        self.cost_type = cost_type
        self.flood_month = flood_month
        self.inundation_period = inundation_period
        self.repair_time_infrastructure = repair_time_infrastructure
        self.repair_time_buildings = repair_time_buildings

    @property
    def basic_post_processing(self):
        """Gets the basic_post_processing of this DamagePostProcessing.  # noqa: E501


        :return: The basic_post_processing of this DamagePostProcessing.  # noqa: E501
        :rtype: int
        """
        return self._basic_post_processing

    @basic_post_processing.setter
    def basic_post_processing(self, basic_post_processing):
        """Sets the basic_post_processing of this DamagePostProcessing.


        :param basic_post_processing: The basic_post_processing of this DamagePostProcessing.  # noqa: E501
        :type: int
        """

        self._basic_post_processing = basic_post_processing

    @property
    def cost_type(self):
        """Gets the cost_type of this DamagePostProcessing.  # noqa: E501

        'min', 'avg', or 'max'  # noqa: E501

        :return: The cost_type of this DamagePostProcessing.  # noqa: E501
        :rtype: str
        """
        return self._cost_type

    @cost_type.setter
    def cost_type(self, cost_type):
        """Sets the cost_type of this DamagePostProcessing.

        'min', 'avg', or 'max'  # noqa: E501

        :param cost_type: The cost_type of this DamagePostProcessing.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and cost_type is None:  # noqa: E501
            raise ValueError("Invalid value for `cost_type`, must not be `None`")  # noqa: E501
        allowed_values = ["min", "avg", "max"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and cost_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `cost_type` ({0}), must be one of {1}"  # noqa: E501
                .format(cost_type, allowed_values)
            )

        self._cost_type = cost_type

    @property
    def flood_month(self):
        """Gets the flood_month of this DamagePostProcessing.  # noqa: E501


        :return: The flood_month of this DamagePostProcessing.  # noqa: E501
        :rtype: str
        """
        return self._flood_month

    @flood_month.setter
    def flood_month(self, flood_month):
        """Sets the flood_month of this DamagePostProcessing.


        :param flood_month: The flood_month of this DamagePostProcessing.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and flood_month is None:  # noqa: E501
            raise ValueError("Invalid value for `flood_month`, must not be `None`")  # noqa: E501
        allowed_values = ["jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and flood_month not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `flood_month` ({0}), must be one of {1}"  # noqa: E501
                .format(flood_month, allowed_values)
            )

        self._flood_month = flood_month

    @property
    def inundation_period(self):
        """Gets the inundation_period of this DamagePostProcessing.  # noqa: E501

        time in hours  # noqa: E501

        :return: The inundation_period of this DamagePostProcessing.  # noqa: E501
        :rtype: float
        """
        return self._inundation_period

    @inundation_period.setter
    def inundation_period(self, inundation_period):
        """Sets the inundation_period of this DamagePostProcessing.

        time in hours  # noqa: E501

        :param inundation_period: The inundation_period of this DamagePostProcessing.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and inundation_period is None:  # noqa: E501
            raise ValueError("Invalid value for `inundation_period`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                inundation_period is not None and inundation_period < 1):  # noqa: E501
            raise ValueError("Invalid value for `inundation_period`, must be a value greater than or equal to `1`")  # noqa: E501

        self._inundation_period = inundation_period

    @property
    def repair_time_infrastructure(self):
        """Gets the repair_time_infrastructure of this DamagePostProcessing.  # noqa: E501

        time in hours  # noqa: E501

        :return: The repair_time_infrastructure of this DamagePostProcessing.  # noqa: E501
        :rtype: int
        """
        return self._repair_time_infrastructure

    @repair_time_infrastructure.setter
    def repair_time_infrastructure(self, repair_time_infrastructure):
        """Sets the repair_time_infrastructure of this DamagePostProcessing.

        time in hours  # noqa: E501

        :param repair_time_infrastructure: The repair_time_infrastructure of this DamagePostProcessing.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and repair_time_infrastructure is None:  # noqa: E501
            raise ValueError("Invalid value for `repair_time_infrastructure`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                repair_time_infrastructure is not None and repair_time_infrastructure > 240):  # noqa: E501
            raise ValueError("Invalid value for `repair_time_infrastructure`, must be a value less than or equal to `240`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                repair_time_infrastructure is not None and repair_time_infrastructure < 1):  # noqa: E501
            raise ValueError("Invalid value for `repair_time_infrastructure`, must be a value greater than or equal to `1`")  # noqa: E501

        self._repair_time_infrastructure = repair_time_infrastructure

    @property
    def repair_time_buildings(self):
        """Gets the repair_time_buildings of this DamagePostProcessing.  # noqa: E501

        time in hours  # noqa: E501

        :return: The repair_time_buildings of this DamagePostProcessing.  # noqa: E501
        :rtype: int
        """
        return self._repair_time_buildings

    @repair_time_buildings.setter
    def repair_time_buildings(self, repair_time_buildings):
        """Sets the repair_time_buildings of this DamagePostProcessing.

        time in hours  # noqa: E501

        :param repair_time_buildings: The repair_time_buildings of this DamagePostProcessing.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and repair_time_buildings is None:  # noqa: E501
            raise ValueError("Invalid value for `repair_time_buildings`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                repair_time_buildings is not None and repair_time_buildings > 240):  # noqa: E501
            raise ValueError("Invalid value for `repair_time_buildings`, must be a value less than or equal to `240`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                repair_time_buildings is not None and repair_time_buildings < 1):  # noqa: E501
            raise ValueError("Invalid value for `repair_time_buildings`, must be a value greater than or equal to `1`")  # noqa: E501

        self._repair_time_buildings = repair_time_buildings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DamagePostProcessing):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DamagePostProcessing):
            return True

        return self.to_dict() != other.to_dict()
